require('../styles/onlyoffice.less')

Promise.all([
    Tine.Tinebase.appMgr.isInitialised('Filemanager'),
    Tine.Tinebase.appMgr.isInitialised('OnlyOfficeIntegrator')
]).then(() => {
    const app = Tine.Tinebase.appMgr.get('OnlyOfficeIntegrator');
    // const templateMap = {
    //     'text': 'new.docx',
    //     'spreadsheet': 'new.xlsx',
    //     'presentation': 'new.pptx'
    // };

    const createDocument = async function (type) {
        const action = this.ownerCt.ownerCt.baseAction;
        const location = action.initialConfig.location;
        const filteredContainers = action.filteredContainers;
        const path = location === 'filemanager' ? _.get(action, 'filteredContainers[0].path') : location;
        const recordData = await Tine.OnlyOfficeIntegrator.createNew(type, path);
        const win = Tine.OnlyOfficeIntegrator.OnlyOfficeEditDialog.openWindow({ recordData: JSON.stringify(recordData), id: recordData.id });

        window.postal.publish({
            channel: "recordchange",
            topic: (location === 'tempFile' ? 'Tinebase.TempFile' : 'Filemanager.Node') + '.create',
            data: recordData
        });
    };

    const createDocumentConfig = {
        app: app,
        allowMultiple: true,
        disabled: true,
        iconCls: 'action_onlyoffice_add',
        scope: this,
        text: app.i18n._('Add Document'),
        menu: [{
            text: app.i18n._('Add Text'),
            iconCls: 'mime-type-application-slash-vnd-dot-msword',
            handler: _.partial(createDocument, 'text')
        }, {
            text: app.i18n._('Add Spreadsheet'),
            iconCls: 'mime-type-application-slash-vnd-dot-ms-excel',
            handler: _.partial(createDocument, 'spreadsheet')
        }, {
            text: app.i18n._('Add Presentation'),
            iconCls: 'mime-type-application-slash-vnd-dot-ms-powerpoint',
            handler: _.partial(createDocument, 'presentation')
        }],
        actionUpdater: function(action, grants, records, isFilterSelect, filteredContainers) {
            const recordData = _.get(filteredContainers, '[0]');
            const isAttachment = _.get(recordData, 'container_id.account_grants', false);

            let enabled = true;
            if (isAttachment) {
                enabled =_.get(recordData, 'container_id.account_grants.editGrant', false);
            } else if (recordData) {
                const node = Tine.Tinebase.data.Record.setFromJson(recordData, Tine.Filemanager.Model.Node);
                enabled = _.get(recordData, 'account_grants.addGrant', false) && ! node.isVirtual();
            }

            action.baseAction.filteredContainers = filteredContainers;

            action.setDisabled(!enabled);
            action.baseAction.setDisabled(!enabled); // WTF?
        }
    };

    // filemanager path
    const fileManagerCreateDocumentAction = new Ext.Action(Ext.applyIf({
        location: 'filemanager'
    }, createDocumentConfig));
    Ext.ux.ItemRegistry.registerItem('Filemanager-Node-GridPanel-ContextMenu', fileManagerCreateDocumentAction, 2);
    Ext.ux.ItemRegistry.registerItem('Filemanager-Node-GridPanel-ActionToolbar-leftbtngrp', Ext.apply(new Ext.Button(fileManagerCreateDocumentAction), {
        scale: 'medium',
        rowspan: 2,
        iconAlign: 'top'
    }), 2);


    // upload grids -> tempFile
    const uploadGridCreateDocumentAction = new Ext.Action(Ext.applyIf({
        location: 'tempFile'
    }, createDocumentConfig));
    Ext.ux.ItemRegistry.registerItem('Tinebase-FileUploadGrid-Toolbar', uploadGridCreateDocumentAction, 5);
    Ext.ux.ItemRegistry.registerItem('Tinebase-FileUploadGrid-ContextMenu', uploadGridCreateDocumentAction, 5);

    // quickadds -> in personal folder
    const quickAddCreateDocumentAction = new Ext.Action(Ext.applyIf({
        location: 'personal',
        disabled: false
    }, createDocumentConfig));
    Ext.ux.ItemRegistry.registerItem('Tine.widgets.grid.GridPanel.addButton', quickAddCreateDocumentAction);

});
