import {getType, isEditable} from "./OnlyOfficeTypes";
require('../styles/onlyoffice.less');

Promise.all([
    Tine.Tinebase.appMgr.isInitialised('Tinebase'),
    Tine.Tinebase.appMgr.isInitialised('Filemanager'),
    Tine.Tinebase.appMgr.isInitialised('OnlyOfficeIntegrator')
]).then(() => {
    const app = Tine.Tinebase.appMgr.get('OnlyOfficeIntegrator');
    const actionConfig = {
        app: app,
        allowMultiple: false,
        disabled: true,
        iconCls: 'action_onlyoffice_edit',
        text: app.i18n._('Open Document'),

        handler: function () {
            const record = this.selections[0];
            const tempFile = record.get('tempFile');
            const recordData = tempFile ? JSON.stringify(tempFile) : record.toString();
            const win = Tine.OnlyOfficeIntegrator.OnlyOfficeEditDialog.openWindow({ recordData: recordData, id: record.id });
        },

        actionUpdater: function (action, grants, records, isFilterSelect) {
            const fileName = _.get(records, '[0].data.name');
            const type = getType(fileName);
            const iconCls = isEditable(fileName)  && _.get(grants, 'editGrant') ? 'action_onlyoffice_edit' :
                type ? 'action_onlyoffice_view' : 'action_onlyoffice';
            const enabled = !isFilterSelect
                && records && records.length === 1
                && ((records[0].get('type') === 'file') || records[0].get('tempFile'))
                && type;

            action.setDisabled(!enabled);
            action.baseAction.setDisabled(!enabled); // WTF?

            action.setIconClass(iconCls);
            action.baseAction.setIconClass(iconCls);
        }
    };

    const editDocumentAction = new Ext.Action(_.assign(actionConfig, {scope: actionConfig}));

    // filemanager
    Ext.ux.ItemRegistry.registerItem('Filemanager-Node-GridPanel-ContextMenu', editDocumentAction, 2);
    Ext.ux.ItemRegistry.registerItem('Filemanager-Node-GridPanel-ActionToolbar-leftbtngrp', Ext.apply(new Ext.Button(editDocumentAction), {
        scale: 'medium',
        rowspan: 2,
        iconAlign: 'top'
    }), 2);


    // upload grids
    Ext.ux.ItemRegistry.registerItem('Tinebase-FileUploadGrid-Toolbar', editDocumentAction, 5);
    Ext.ux.ItemRegistry.registerItem('Tinebase-FileUploadGrid-ContextMenu', editDocumentAction, 5);

    // preview panel
    Ext.ux.ItemRegistry.registerItem('Tine-Filemanager-DocumentPreview', editDocumentAction, 100);

    // dblclick actions
    Tine.on('filesystem.fileDoubleClick', (fileNode, dblClickHandlers) => {
        const fileName = _.get(fileNode, 'data.name');
        const type = getType(fileName);

        if (type) {
            dblClickHandlers.push({
                prio: 1000,
                fn: _.bind(editDocumentAction.execute, editDocumentAction)
            })
        }
    });
});
